@@ -1,15 +1,12 @@
 # -*- coding: utf-8 -*-
 
-from pathlib import Path
 from random import randint
 
 import numpy as np
 from scipy import ndimage as ndi
 from skimage import data
 from skimage.draw import ellipse
-from skimage.feature import register_translation
 from skimage.filters import gaussian
-from skimage.transform import rotate
 import skimage.data as data
 
 from skued import align, ialign, itrack_peak
@@ -24,7 +21,7 @@ def circle_image(shape, center, radii, intensities):
     xx, yy = np.ogrid[0 : shape[0], 0 : shape[1]]
     xx, yy = xx - center[0], yy - center[1]
     for radius, intensity in zip(radii, intensities):
-        rr = np.sqrt(xx ** 2 + yy ** 2)
+        rr = np.sqrt(xx**2 + yy**2)
         im[np.logical_and(rr < radius + 1, rr > radius - 1)] = intensity
 
     im[:] = gaussian(im, 5)
