@@ -2,14 +2,8 @@
 """
 Structure Factor calculation
 """
-from collections.abc import Iterable
-from functools import lru_cache
-from itertools import count, product, takewhile
-from math import sqrt
 
 import numpy as np
-from npstreams import primed
-from numpy.linalg import norm
 
 from crystals.affine import change_basis_mesh
 
@@ -48,7 +42,7 @@ def structure_factor(crystal, h, k, l, normalized=False):
     Gx, Gy, Gz = change_basis_mesh(
         h, k, l, basis1=crystal.reciprocal_vectors, basis2=np.eye(3)
     )
-    nG = np.sqrt(Gx ** 2 + Gy ** 2 + Gz ** 2)
+    nG = np.sqrt(Gx**2 + Gy**2 + Gz**2)
 
     # Separating the structure factor into sine and cosine parts avoids adding
     # complex arrays together. About 3x speedup vs. using complex exponentials
