@@ -50,10 +50,10 @@ def gaussian(coordinates, center, fwhm=None, std=None):
     >>> np.sum(g)*0.1**2   # Integral should be close to unity (spacing = 0.1)
     1.0000000000000075
     """
-    if not any([fwhm, std]):
+    if all([fwhm is None, std is None]):
         raise ValueError("Either fwhm or std has to be provided")
 
-    if fwhm:
+    if fwhm is not None:
         std = fwhm / (2 * np.sqrt(2 * np.log(2)))
 
         # 1D is a special case, as coordinates are not given as a list of arrays
@@ -126,11 +126,11 @@ def lorentzian(coordinates, center, fwhm):
 
     # 1D is a special case, as coordinates are not given as a list of arrays
     if not isinstance(coordinates, (list, tuple)):  # iterable but not ndarray
-        return (width / pi) / ((coordinates - center) ** 2 + width ** 2)
+        return (width / pi) / ((coordinates - center) ** 2 + width**2)
 
     dim = len(coordinates)
     core = width / (
-        (sum([(x - c) ** 2 for x, c in zip(coordinates, center)]) + width ** 2)
+        (sum([(x - c) ** 2 for x, c in zip(coordinates, center)]) + width**2)
     ) ** ((dim + 1) / 2)
     factor = 1 / (dim * pi)
     return factor * core
@@ -155,12 +155,12 @@ def _pseudo_voigt_mixing_factor(width_l, width_g):
     # Fast formula (see paper in pseudo_voigt docstrings)
     # This assumes width_g and width_l are the Gaussian FWHM and Lorentzian FWHM
     gamma = (
-        width_g ** 5
-        + 2.69269 * width_l * (width_g ** 4)
-        + 2.42843 * (width_l ** 2) * (width_g ** 3)
-        + 4.47163 * (width_l ** 3) * (width_g ** 2)
-        + 0.07842 * (width_l ** 4) * width_g
-        + width_l ** 5
+        width_g**5
+        + 2.69269 * width_l * (width_g**4)
+        + 2.42843 * (width_l**2) * (width_g**3)
+        + 4.47163 * (width_l**3) * (width_g**2)
+        + 0.07842 * (width_l**4) * width_g
+        + width_l**5
     ) ** (1 / 5)
 
     # Proportion of the Voigt that should be Lorentzian
